CreateNotifyCodeConfigurationFluentBuilder

Struct CreateNotifyCodeConfigurationFluentBuilder 

pub struct CreateNotifyCodeConfigurationFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateNotifyCodeConfiguration.

Creates a notify code configuration. A notify code configuration is a reusable policy that defines how one-time passcodes are generated and rendered, including the code type, length, validity period, maximum number of attempts, and channel templates.

Implementations

Source

impl CreateNotifyCodeConfigurationFluentBuilder

pub fn as_input(&self) -> &CreateNotifyCodeConfigurationInputBuilder

Access the CreateNotifyCodeConfiguration as a reference.

pub async fn send( self, ) -> Result<CreateNotifyCodeConfigurationOutput, SdkError<CreateNotifyCodeConfigurationError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateNotifyCodeConfigurationOutput, CreateNotifyCodeConfigurationError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn notify_code_configuration_name(self, input: impl Into<String>) -> Self

The name of the notify code configuration.

pub fn set_notify_code_configuration_name(self, input: Option<String>) -> Self

The name of the notify code configuration.

pub fn get_notify_code_configuration_name(&self) -> &Option<String>

The name of the notify code configuration.

pub fn code_configuration_parameters( self, input: CodeConfigurationParameters, ) -> Self

The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.

pub fn set_code_configuration_parameters( self, input: Option<CodeConfigurationParameters>, ) -> Self

The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.

pub fn get_code_configuration_parameters( &self, ) -> &Option<CodeConfigurationParameters>

The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.

pub fn channel_parameters(self, input: ChannelParameters) -> Self

The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.

pub fn set_channel_parameters(self, input: Option<ChannelParameters>) -> Self

The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.

pub fn get_channel_parameters(&self) -> &Option<ChannelParameters>

The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.

pub fn deletion_protection_enabled(self, input: bool) -> Self

Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.

pub fn set_deletion_protection_enabled(self, input: Option<bool>) -> Self

Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.

pub fn get_deletion_protection_enabled(&self) -> &Option<bool>

Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.

pub fn client_token(self, input: impl Into<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.

pub fn set_client_token(self, input: Option<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.

pub fn get_client_token(&self) -> &Option<String>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.

pub fn tags(self, input: Tag) -> Self

Appends an item to tags.

To override the contents of this collection use set_tags.

An array of key and value pair tags that are associated with the resource.

pub fn set_tags(self, input: Option<Vec<Tag>>) -> Self

An array of key and value pair tags that are associated with the resource.

pub fn get_tags(&self) -> &Option<Vec<Tag>>

An array of key and value pair tags that are associated with the resource.