#[non_exhaustive]pub struct CreateNotifyCodeConfigurationInputBuilder { /* private fields */ }Expand description
A builder for CreateNotifyCodeConfigurationInput.
Implementations
Sourceimpl CreateNotifyCodeConfigurationInputBuilder
impl CreateNotifyCodeConfigurationInputBuilder
Sourcepub fn notify_code_configuration_name(self, input: impl Into<String>) -> Self
pub fn notify_code_configuration_name(self, input: impl Into<String>) -> Self
The name of the notify code configuration.
This field is required.Sourcepub fn set_notify_code_configuration_name(self, input: Option<String>) -> Self
pub fn set_notify_code_configuration_name(self, input: Option<String>) -> Self
The name of the notify code configuration.
Sourcepub fn get_notify_code_configuration_name(&self) -> &Option<String>
pub fn get_notify_code_configuration_name(&self) -> &Option<String>
The name of the notify code configuration.
Sourcepub fn code_configuration_parameters(
self,
input: CodeConfigurationParameters,
) -> Self
pub fn code_configuration_parameters( self, input: CodeConfigurationParameters, ) -> Self
The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.
Sourcepub fn set_code_configuration_parameters(
self,
input: Option<CodeConfigurationParameters>,
) -> Self
pub fn set_code_configuration_parameters( self, input: Option<CodeConfigurationParameters>, ) -> Self
The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.
Sourcepub fn get_code_configuration_parameters(
&self,
) -> &Option<CodeConfigurationParameters>
pub fn get_code_configuration_parameters( &self, ) -> &Option<CodeConfigurationParameters>
The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.
Sourcepub fn channel_parameters(self, input: ChannelParameters) -> Self
pub fn channel_parameters(self, input: ChannelParameters) -> Self
The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.
Sourcepub fn set_channel_parameters(self, input: Option<ChannelParameters>) -> Self
pub fn set_channel_parameters(self, input: Option<ChannelParameters>) -> Self
The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.
Sourcepub fn get_channel_parameters(&self) -> &Option<ChannelParameters>
pub fn get_channel_parameters(&self) -> &Option<ChannelParameters>
The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.
Sourcepub fn deletion_protection_enabled(self, input: bool) -> Self
pub fn deletion_protection_enabled(self, input: bool) -> Self
Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.
Sourcepub fn set_deletion_protection_enabled(self, input: Option<bool>) -> Self
pub fn set_deletion_protection_enabled(self, input: Option<bool>) -> Self
Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.
Sourcepub fn get_deletion_protection_enabled(&self) -> &Option<bool>
pub fn get_deletion_protection_enabled(&self) -> &Option<bool>
Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.
Appends an item to tags.
To override the contents of this collection use set_tags.
An array of key and value pair tags that are associated with the resource.
An array of key and value pair tags that are associated with the resource.
An array of key and value pair tags that are associated with the resource.
Sourcepub fn build(self) -> Result<CreateNotifyCodeConfigurationInput, BuildError>
pub fn build(self) -> Result<CreateNotifyCodeConfigurationInput, BuildError>
Consumes the builder and constructs a CreateNotifyCodeConfigurationInput.
Sourceimpl CreateNotifyCodeConfigurationInputBuilder
impl CreateNotifyCodeConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateNotifyCodeConfigurationOutput, SdkError<CreateNotifyCodeConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateNotifyCodeConfigurationOutput, SdkError<CreateNotifyCodeConfigurationError, HttpResponse>>
Sends a request with this input using the given client.