#[non_exhaustive]pub struct CreateNotifyCodeConfigurationInput {
pub notify_code_configuration_name: Option<String>,
pub code_configuration_parameters: Option<CodeConfigurationParameters>,
pub channel_parameters: Option<ChannelParameters>,
pub deletion_protection_enabled: Option<bool>,
pub client_token: Option<String>,
pub tags: Option<Vec<Tag>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notify_code_configuration_name: Option<String>The name of the notify code configuration.
code_configuration_parameters: Option<CodeConfigurationParameters>The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.
channel_parameters: Option<ChannelParameters>The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.
deletion_protection_enabled: Option<bool>Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.
An array of key and value pair tags that are associated with the resource.
Implementations
Sourceimpl CreateNotifyCodeConfigurationInput
impl CreateNotifyCodeConfigurationInput
Sourcepub fn notify_code_configuration_name(&self) -> Option<&str>
pub fn notify_code_configuration_name(&self) -> Option<&str>
The name of the notify code configuration.
Sourcepub fn code_configuration_parameters(
&self,
) -> Option<&CodeConfigurationParameters>
pub fn code_configuration_parameters( &self, ) -> Option<&CodeConfigurationParameters>
The passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. Each member is optional. When you omit a member, no value is applied at create time and the default is applied when a passcode is sent.
Sourcepub fn channel_parameters(&self) -> Option<&ChannelParameters>
pub fn channel_parameters(&self) -> Option<&ChannelParameters>
The channel-specific parameters used to render and deliver the one-time passcode. Provide parameters for any subset of channels. Each member configures one delivery route, and the route that is selected at send time uses the matching channel.
Sourcepub fn deletion_protection_enabled(&self) -> Option<bool>
pub fn deletion_protection_enabled(&self) -> Option<bool>
Specifies whether deletion protection is enabled. When enabled, the resource cannot be deleted until deletion protection is turned off.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you do not specify a client token, the AWS SDK automatically generates one.
An array of key and value pair tags that are associated with the resource.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl CreateNotifyCodeConfigurationInput
impl CreateNotifyCodeConfigurationInput
Sourcepub fn builder() -> CreateNotifyCodeConfigurationInputBuilder
pub fn builder() -> CreateNotifyCodeConfigurationInputBuilder
Creates a new builder-style object to manufacture CreateNotifyCodeConfigurationInput.