#[non_exhaustive]pub struct SendNotifyCodeVerificationInput {
pub channel: Option<NotifyChannel>,
pub destination_identity: Option<String>,
pub origination_identity: Option<String>,
pub notify_code_configuration: Option<String>,
pub override_channel_parameters: Option<ChannelParameters>,
pub override_code_configuration_parameters: Option<CodeConfigurationParameters>,
pub configuration_set_name: Option<String>,
pub context: Option<HashMap<String, String>>,
pub reference_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: Option<NotifyChannel>The channel used to deliver the one-time passcode to the recipient.
destination_identity: Option<String>The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
origination_identity: Option<String>The identity used to send the message, such as a phone number, sender ID, or pool that is owned by your account.
notify_code_configuration: Option<String>The identifier or Amazon Resource Name (ARN) of the notify code configuration that supplies the passcode policy and template defaults. When you do not specify a configuration, you must supply the template in the request.
override_channel_parameters: Option<ChannelParameters>The channel-specific parameters used to render and deliver the one-time passcode for this request. The route that is derived from the channel and the origination identity selects the matching channel. When you do not specify channel parameters, the service uses the parameters from the referenced notify code configuration.
override_code_configuration_parameters: Option<CodeConfigurationParameters>The per-send overrides for the passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. These values override the values from the referenced notify code configuration. When you do not specify a value, the value from the configuration is used, and if neither is set, the service default applies.
configuration_set_name: Option<String>The name of the configuration set used to control how delivery events for the message are handled.
context: Option<HashMap<String, String>>A map of custom key and value pairs that are propagated to the delivery events for this verification.
reference_id: Option<String>A caller-supplied reference identifier that binds a send request to a later validate request. Specify the same value in both requests.
Implementations
Sourceimpl SendNotifyCodeVerificationInput
impl SendNotifyCodeVerificationInput
Sourcepub fn channel(&self) -> Option<&NotifyChannel>
pub fn channel(&self) -> Option<&NotifyChannel>
The channel used to deliver the one-time passcode to the recipient.
Sourcepub fn destination_identity(&self) -> Option<&str>
pub fn destination_identity(&self) -> Option<&str>
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn origination_identity(&self) -> Option<&str>
pub fn origination_identity(&self) -> Option<&str>
The identity used to send the message, such as a phone number, sender ID, or pool that is owned by your account.
Sourcepub fn notify_code_configuration(&self) -> Option<&str>
pub fn notify_code_configuration(&self) -> Option<&str>
The identifier or Amazon Resource Name (ARN) of the notify code configuration that supplies the passcode policy and template defaults. When you do not specify a configuration, you must supply the template in the request.
Sourcepub fn override_channel_parameters(&self) -> Option<&ChannelParameters>
pub fn override_channel_parameters(&self) -> Option<&ChannelParameters>
The channel-specific parameters used to render and deliver the one-time passcode for this request. The route that is derived from the channel and the origination identity selects the matching channel. When you do not specify channel parameters, the service uses the parameters from the referenced notify code configuration.
Sourcepub fn override_code_configuration_parameters(
&self,
) -> Option<&CodeConfigurationParameters>
pub fn override_code_configuration_parameters( &self, ) -> Option<&CodeConfigurationParameters>
The per-send overrides for the passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. These values override the values from the referenced notify code configuration. When you do not specify a value, the value from the configuration is used, and if neither is set, the service default applies.
Sourcepub fn configuration_set_name(&self) -> Option<&str>
pub fn configuration_set_name(&self) -> Option<&str>
The name of the configuration set used to control how delivery events for the message are handled.
Sourcepub fn context(&self) -> Option<&HashMap<String, String>>
pub fn context(&self) -> Option<&HashMap<String, String>>
A map of custom key and value pairs that are propagated to the delivery events for this verification.
Sourcepub fn reference_id(&self) -> Option<&str>
pub fn reference_id(&self) -> Option<&str>
A caller-supplied reference identifier that binds a send request to a later validate request. Specify the same value in both requests.
Sourceimpl SendNotifyCodeVerificationInput
impl SendNotifyCodeVerificationInput
Sourcepub fn builder() -> SendNotifyCodeVerificationInputBuilder
pub fn builder() -> SendNotifyCodeVerificationInputBuilder
Creates a new builder-style object to manufacture SendNotifyCodeVerificationInput.