#[non_exhaustive]pub struct SendNotifyCodeVerificationOutput {
pub verification_id: String,
pub message_id: String,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.verification_id: StringThe service-generated identifier for the verification.
message_id: StringThe service-generated identifier for the message that delivers the one-time passcode.
Implementations
Sourceimpl SendNotifyCodeVerificationOutput
impl SendNotifyCodeVerificationOutput
Sourcepub fn verification_id(&self) -> &str
pub fn verification_id(&self) -> &str
The service-generated identifier for the verification.
Sourcepub fn message_id(&self) -> &str
pub fn message_id(&self) -> &str
The service-generated identifier for the message that delivers the one-time passcode.
Sourceimpl SendNotifyCodeVerificationOutput
impl SendNotifyCodeVerificationOutput
Sourcepub fn builder() -> SendNotifyCodeVerificationOutputBuilder
pub fn builder() -> SendNotifyCodeVerificationOutputBuilder
Creates a new builder-style object to manufacture SendNotifyCodeVerificationOutput.