ValidateNotifyCodeVerificationFluentBuilder

Struct ValidateNotifyCodeVerificationFluentBuilder 

pub struct ValidateNotifyCodeVerificationFluentBuilder { /* private fields */ }
Fluent builder constructing a request to ValidateNotifyCodeVerification.

Validates a one-time passcode that a recipient submitted. Validation succeeds when the passcode matches, the validity period has not elapsed, and the maximum number of attempts has not been exceeded.

Implementations

Source

impl ValidateNotifyCodeVerificationFluentBuilder

pub fn as_input(&self) -> &ValidateNotifyCodeVerificationInputBuilder

Access the ValidateNotifyCodeVerification as a reference.

pub async fn send( self, ) -> Result<ValidateNotifyCodeVerificationOutput, SdkError<ValidateNotifyCodeVerificationError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<ValidateNotifyCodeVerificationOutput, ValidateNotifyCodeVerificationError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn destination_identity(self, input: impl Into<String>) -> Self

The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.

pub fn set_destination_identity(self, input: Option<String>) -> Self

The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.

pub fn get_destination_identity(&self) -> &Option<String>

The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.

pub fn reference_id(self, input: impl Into<String>) -> Self

The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.

pub fn set_reference_id(self, input: Option<String>) -> Self

The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.

pub fn get_reference_id(&self) -> &Option<String>

The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.

pub fn code(self, input: impl Into<String>) -> Self

The one-time passcode that the recipient submitted for validation.

pub fn set_code(self, input: Option<String>) -> Self

The one-time passcode that the recipient submitted for validation.

pub fn get_code(&self) -> &Option<String>

The one-time passcode that the recipient submitted for validation.