#[non_exhaustive]pub struct ValidateNotifyCodeVerificationInputBuilder { /* private fields */ }Expand description
A builder for ValidateNotifyCodeVerificationInput.
Implementations
Sourceimpl ValidateNotifyCodeVerificationInputBuilder
impl ValidateNotifyCodeVerificationInputBuilder
Sourcepub fn destination_identity(self, input: impl Into<String>) -> Self
pub fn destination_identity(self, input: impl Into<String>) -> Self
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
This field is required.Sourcepub fn set_destination_identity(self, input: Option<String>) -> Self
pub fn set_destination_identity(self, input: Option<String>) -> Self
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn get_destination_identity(&self) -> &Option<String>
pub fn get_destination_identity(&self) -> &Option<String>
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn reference_id(self, input: impl Into<String>) -> Self
pub fn reference_id(self, input: impl Into<String>) -> Self
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourcepub fn set_reference_id(self, input: Option<String>) -> Self
pub fn set_reference_id(self, input: Option<String>) -> Self
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourcepub fn get_reference_id(&self) -> &Option<String>
pub fn get_reference_id(&self) -> &Option<String>
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourcepub fn code(self, input: impl Into<String>) -> Self
pub fn code(self, input: impl Into<String>) -> Self
The one-time passcode that the recipient submitted for validation.
This field is required.Sourcepub fn set_code(self, input: Option<String>) -> Self
pub fn set_code(self, input: Option<String>) -> Self
The one-time passcode that the recipient submitted for validation.
Sourcepub fn get_code(&self) -> &Option<String>
pub fn get_code(&self) -> &Option<String>
The one-time passcode that the recipient submitted for validation.
Sourcepub fn build(self) -> Result<ValidateNotifyCodeVerificationInput, BuildError>
pub fn build(self) -> Result<ValidateNotifyCodeVerificationInput, BuildError>
Consumes the builder and constructs a ValidateNotifyCodeVerificationInput.
Sourceimpl ValidateNotifyCodeVerificationInputBuilder
impl ValidateNotifyCodeVerificationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ValidateNotifyCodeVerificationOutput, SdkError<ValidateNotifyCodeVerificationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ValidateNotifyCodeVerificationOutput, SdkError<ValidateNotifyCodeVerificationError, HttpResponse>>
Sends a request with this input using the given client.