#[non_exhaustive]pub struct ValidateNotifyCodeVerificationInput {
pub destination_identity: Option<String>,
pub reference_id: Option<String>,
pub code: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.destination_identity: Option<String>The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
reference_id: Option<String>The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
code: Option<String>The one-time passcode that the recipient submitted for validation.
Implementations
Sourceimpl ValidateNotifyCodeVerificationInput
impl ValidateNotifyCodeVerificationInput
Sourcepub fn destination_identity(&self) -> Option<&str>
pub fn destination_identity(&self) -> Option<&str>
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn reference_id(&self) -> Option<&str>
pub fn reference_id(&self) -> Option<&str>
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourceimpl ValidateNotifyCodeVerificationInput
impl ValidateNotifyCodeVerificationInput
Sourcepub fn builder() -> ValidateNotifyCodeVerificationInputBuilder
pub fn builder() -> ValidateNotifyCodeVerificationInputBuilder
Creates a new builder-style object to manufacture ValidateNotifyCodeVerificationInput.