#[non_exhaustive]pub struct CodeConfigurationParametersBuilder { /* private fields */ }Expand description
A builder for CodeConfigurationParameters.
Implementations
Sourceimpl CodeConfigurationParametersBuilder
impl CodeConfigurationParametersBuilder
Sourcepub fn code_type(self, input: CodeType) -> Self
pub fn code_type(self, input: CodeType) -> Self
The character set used to generate the one-time passcode. Valid values are NUMERIC (digits only), ALPHA (uppercase letters only), and ALPHANUMERIC (uppercase letters and digits). When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn set_code_type(self, input: Option<CodeType>) -> Self
pub fn set_code_type(self, input: Option<CodeType>) -> Self
The character set used to generate the one-time passcode. Valid values are NUMERIC (digits only), ALPHA (uppercase letters only), and ALPHANUMERIC (uppercase letters and digits). When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn get_code_type(&self) -> &Option<CodeType>
pub fn get_code_type(&self) -> &Option<CodeType>
The character set used to generate the one-time passcode. Valid values are NUMERIC (digits only), ALPHA (uppercase letters only), and ALPHANUMERIC (uppercase letters and digits). When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn code_length(self, input: i32) -> Self
pub fn code_length(self, input: i32) -> Self
The number of characters in the one-time passcode. Valid values range from 4 through 8. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn set_code_length(self, input: Option<i32>) -> Self
pub fn set_code_length(self, input: Option<i32>) -> Self
The number of characters in the one-time passcode. Valid values range from 4 through 8. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn get_code_length(&self) -> &Option<i32>
pub fn get_code_length(&self) -> &Option<i32>
The number of characters in the one-time passcode. Valid values range from 4 through 8. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn validity_period_minutes(self, input: i32) -> Self
pub fn validity_period_minutes(self, input: i32) -> Self
The length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn set_validity_period_minutes(self, input: Option<i32>) -> Self
pub fn set_validity_period_minutes(self, input: Option<i32>) -> Self
The length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn get_validity_period_minutes(&self) -> &Option<i32>
pub fn get_validity_period_minutes(&self) -> &Option<i32>
The length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn max_attempts(self, input: i32) -> Self
pub fn max_attempts(self, input: i32) -> Self
The maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn set_max_attempts(self, input: Option<i32>) -> Self
pub fn set_max_attempts(self, input: Option<i32>) -> Self
The maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn get_max_attempts(&self) -> &Option<i32>
pub fn get_max_attempts(&self) -> &Option<i32>
The maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn build(self) -> CodeConfigurationParameters
pub fn build(self) -> CodeConfigurationParameters
Consumes the builder and constructs a CodeConfigurationParameters.