#[non_exhaustive]pub struct UpdateCodeConfigurationParametersBuilder { /* private fields */ }Expand description
A builder for UpdateCodeConfigurationParameters.
Implementations
Sourceimpl UpdateCodeConfigurationParametersBuilder
impl UpdateCodeConfigurationParametersBuilder
Sourcepub fn code_type(self, input: CodeType) -> Self
pub fn code_type(self, input: CodeType) -> Self
The updated character set used to generate the one-time passcode. Omit this member to preserve the current value.
Sourcepub fn set_code_type(self, input: Option<CodeType>) -> Self
pub fn set_code_type(self, input: Option<CodeType>) -> Self
The updated character set used to generate the one-time passcode. Omit this member to preserve the current value.
Sourcepub fn get_code_type(&self) -> &Option<CodeType>
pub fn get_code_type(&self) -> &Option<CodeType>
The updated character set used to generate the one-time passcode. Omit this member to preserve the current value.
Sourcepub fn code_length(self, input: i32) -> Self
pub fn code_length(self, input: i32) -> Self
The updated number of characters in the one-time passcode. Valid values range from 4 through 8. Omit this member to preserve the current value.
Sourcepub fn set_code_length(self, input: Option<i32>) -> Self
pub fn set_code_length(self, input: Option<i32>) -> Self
The updated number of characters in the one-time passcode. Valid values range from 4 through 8. Omit this member to preserve the current value.
Sourcepub fn get_code_length(&self) -> &Option<i32>
pub fn get_code_length(&self) -> &Option<i32>
The updated number of characters in the one-time passcode. Valid values range from 4 through 8. Omit this member to preserve the current value.
Sourcepub fn validity_period_minutes(self, input: i32) -> Self
pub fn validity_period_minutes(self, input: i32) -> Self
The updated length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. Omit this member to preserve the current value.
Sourcepub fn set_validity_period_minutes(self, input: Option<i32>) -> Self
pub fn set_validity_period_minutes(self, input: Option<i32>) -> Self
The updated length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. Omit this member to preserve the current value.
Sourcepub fn get_validity_period_minutes(&self) -> &Option<i32>
pub fn get_validity_period_minutes(&self) -> &Option<i32>
The updated length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. Omit this member to preserve the current value.
Sourcepub fn max_attempts(self, input: i32) -> Self
pub fn max_attempts(self, input: i32) -> Self
The updated maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. Omit this member to preserve the current value.
Sourcepub fn set_max_attempts(self, input: Option<i32>) -> Self
pub fn set_max_attempts(self, input: Option<i32>) -> Self
The updated maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. Omit this member to preserve the current value.
Sourcepub fn get_max_attempts(&self) -> &Option<i32>
pub fn get_max_attempts(&self) -> &Option<i32>
The updated maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. Omit this member to preserve the current value.
Sourcepub fn build(self) -> UpdateCodeConfigurationParameters
pub fn build(self) -> UpdateCodeConfigurationParameters
Consumes the builder and constructs a UpdateCodeConfigurationParameters.