#[non_exhaustive]pub struct CodeConfigurationParameters {
pub code_type: Option<CodeType>,
pub code_length: Option<i32>,
pub validity_period_minutes: Option<i32>,
pub max_attempts: Option<i32>,
}Expand description
The passcode policy parameters that are grouped for reuse across a notify code configuration and its create request. Each member is optional. When you omit a member on a create request, no value is applied at create time and the default is applied when a passcode is sent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_type: Option<CodeType>The character set used to generate the one-time passcode. Valid values are NUMERIC (digits only), ALPHA (uppercase letters only), and ALPHANUMERIC (uppercase letters and digits). When you do not specify a value, the default is applied when a passcode is sent.
code_length: Option<i32>The number of characters in the one-time passcode. Valid values range from 4 through 8. When you do not specify a value, the default is applied when a passcode is sent.
validity_period_minutes: Option<i32>The length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. When you do not specify a value, the default is applied when a passcode is sent.
max_attempts: Option<i32>The maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. When you do not specify a value, the default is applied when a passcode is sent.
Implementations
Sourceimpl CodeConfigurationParameters
impl CodeConfigurationParameters
Sourcepub fn code_type(&self) -> Option<&CodeType>
pub fn code_type(&self) -> Option<&CodeType>
The character set used to generate the one-time passcode. Valid values are NUMERIC (digits only), ALPHA (uppercase letters only), and ALPHANUMERIC (uppercase letters and digits). When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn code_length(&self) -> Option<i32>
pub fn code_length(&self) -> Option<i32>
The number of characters in the one-time passcode. Valid values range from 4 through 8. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn validity_period_minutes(&self) -> Option<i32>
pub fn validity_period_minutes(&self) -> Option<i32>
The length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. When you do not specify a value, the default is applied when a passcode is sent.
Sourcepub fn max_attempts(&self) -> Option<i32>
pub fn max_attempts(&self) -> Option<i32>
The maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. When you do not specify a value, the default is applied when a passcode is sent.
Sourceimpl CodeConfigurationParameters
impl CodeConfigurationParameters
Sourcepub fn builder() -> CodeConfigurationParametersBuilder
pub fn builder() -> CodeConfigurationParametersBuilder
Creates a new builder-style object to manufacture CodeConfigurationParameters.