#[non_exhaustive]pub struct TextParameters {
pub inline_template_body: Option<String>,
pub destination_country_parameters: Option<HashMap<String, String>>,
}Expand description
The delivery parameters for the text channel, which delivers over SMS or RCS.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inline_template_body: Option<String>The freeform message template used to render the one-time passcode for the SMS or RCS channels. The template must contain the code placeholder.
destination_country_parameters: Option<HashMap<String, String>>A map of country-specific parameters that control one-time passcode delivery.
Implementations
Sourceimpl TextParameters
impl TextParameters
Sourcepub fn inline_template_body(&self) -> Option<&str>
pub fn inline_template_body(&self) -> Option<&str>
The freeform message template used to render the one-time passcode for the SMS or RCS channels. The template must contain the code placeholder.
Sourceimpl TextParameters
impl TextParameters
Sourcepub fn builder() -> TextParametersBuilder
pub fn builder() -> TextParametersBuilder
Creates a new builder-style object to manufacture TextParameters.