#[non_exhaustive]pub struct UpdateCodeConfigurationParameters {
pub code_type: Option<CodeType>,
pub code_length: Option<i32>,
pub validity_period_minutes: Option<i32>,
pub max_attempts: Option<i32>,
}Expand description
The loose variant of the passcode policy parameters that is used only when you update a notify code configuration. When you omit a member, its current value is preserved.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.code_type: Option<CodeType>The updated character set used to generate the one-time passcode. Omit this member to preserve the current value.
code_length: Option<i32>The updated number of characters in the one-time passcode. Valid values range from 4 through 8. Omit this member to preserve the current value.
validity_period_minutes: Option<i32>The updated length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. Omit this member to preserve the current value.
max_attempts: Option<i32>The updated maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. Omit this member to preserve the current value.
Implementations
Sourceimpl UpdateCodeConfigurationParameters
impl UpdateCodeConfigurationParameters
Sourcepub fn code_type(&self) -> Option<&CodeType>
pub fn code_type(&self) -> Option<&CodeType>
The updated character set used to generate the one-time passcode. Omit this member to preserve the current value.
Sourcepub fn code_length(&self) -> Option<i32>
pub fn code_length(&self) -> Option<i32>
The updated number of characters in the one-time passcode. Valid values range from 4 through 8. Omit this member to preserve the current value.
Sourcepub fn validity_period_minutes(&self) -> Option<i32>
pub fn validity_period_minutes(&self) -> Option<i32>
The updated length of time, in minutes, that the one-time passcode remains valid. Valid values range from 1 through 60. Omit this member to preserve the current value.
Sourcepub fn max_attempts(&self) -> Option<i32>
pub fn max_attempts(&self) -> Option<i32>
The updated maximum number of validation attempts that are allowed before the verification is locked. Valid values range from 1 through 5. Omit this member to preserve the current value.
Sourceimpl UpdateCodeConfigurationParameters
impl UpdateCodeConfigurationParameters
Sourcepub fn builder() -> UpdateCodeConfigurationParametersBuilder
pub fn builder() -> UpdateCodeConfigurationParametersBuilder
Creates a new builder-style object to manufacture UpdateCodeConfigurationParameters.