#[non_exhaustive]pub struct UpdateNotifyParameters {
pub notify_template_id: Option<String>,
pub voice_id: Option<String>,
}Expand description
The updated delivery parameters for the preapproved notify-template route. Absent members preserve the current value, and the empty sentinel on a member clears it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notify_template_id: Option<String>The updated identifier of a preapproved notify template for the SMS or voice channels. An empty string clears the previously stored value.
voice_id: Option<String>The updated Amazon Polly voice ID. An empty string clears the previously stored value.
Implementations
Sourceimpl UpdateNotifyParameters
impl UpdateNotifyParameters
Sourcepub fn notify_template_id(&self) -> Option<&str>
pub fn notify_template_id(&self) -> Option<&str>
The updated identifier of a preapproved notify template for the SMS or voice channels. An empty string clears the previously stored value.
Sourceimpl UpdateNotifyParameters
impl UpdateNotifyParameters
Sourcepub fn builder() -> UpdateNotifyParametersBuilder
pub fn builder() -> UpdateNotifyParametersBuilder
Creates a new builder-style object to manufacture UpdateNotifyParameters.