pub struct SendNotifyCodeVerificationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to SendNotifyCodeVerification.
Generates a one-time passcode and delivers it to a recipient over the requested channel. The passcode policy is captured from the referenced notify code configuration at the time of the request, so later updates to the configuration do not affect verifications that are already in progress.
Implementations
Sourceimpl SendNotifyCodeVerificationFluentBuilder
impl SendNotifyCodeVerificationFluentBuilder
Sourcepub fn as_input(&self) -> &SendNotifyCodeVerificationInputBuilder
pub fn as_input(&self) -> &SendNotifyCodeVerificationInputBuilder
Access the SendNotifyCodeVerification as a reference.
Sourcepub async fn send(
self,
) -> Result<SendNotifyCodeVerificationOutput, SdkError<SendNotifyCodeVerificationError, HttpResponse>>
pub async fn send( self, ) -> Result<SendNotifyCodeVerificationOutput, SdkError<SendNotifyCodeVerificationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<SendNotifyCodeVerificationOutput, SendNotifyCodeVerificationError, Self>
pub fn customize( self, ) -> CustomizableOperation<SendNotifyCodeVerificationOutput, SendNotifyCodeVerificationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn channel(self, input: NotifyChannel) -> Self
pub fn channel(self, input: NotifyChannel) -> Self
The channel used to deliver the one-time passcode to the recipient.
Sourcepub fn set_channel(self, input: Option<NotifyChannel>) -> Self
pub fn set_channel(self, input: Option<NotifyChannel>) -> Self
The channel used to deliver the one-time passcode to the recipient.
Sourcepub fn get_channel(&self) -> &Option<NotifyChannel>
pub fn get_channel(&self) -> &Option<NotifyChannel>
The channel used to deliver the one-time passcode to the recipient.
Sourcepub fn destination_identity(self, input: impl Into<String>) -> Self
pub fn destination_identity(self, input: impl Into<String>) -> Self
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn set_destination_identity(self, input: Option<String>) -> Self
pub fn set_destination_identity(self, input: Option<String>) -> Self
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn get_destination_identity(&self) -> &Option<String>
pub fn get_destination_identity(&self) -> &Option<String>
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn origination_identity(self, input: impl Into<String>) -> Self
pub fn origination_identity(self, input: impl Into<String>) -> Self
The identity used to send the message, such as a phone number, sender ID, or pool that is owned by your account.
Sourcepub fn set_origination_identity(self, input: Option<String>) -> Self
pub fn set_origination_identity(self, input: Option<String>) -> Self
The identity used to send the message, such as a phone number, sender ID, or pool that is owned by your account.
Sourcepub fn get_origination_identity(&self) -> &Option<String>
pub fn get_origination_identity(&self) -> &Option<String>
The identity used to send the message, such as a phone number, sender ID, or pool that is owned by your account.
Sourcepub fn notify_code_configuration(self, input: impl Into<String>) -> Self
pub fn notify_code_configuration(self, input: impl Into<String>) -> Self
The identifier or Amazon Resource Name (ARN) of the notify code configuration that supplies the passcode policy and template defaults. When you do not specify a configuration, you must supply the template in the request.
Sourcepub fn set_notify_code_configuration(self, input: Option<String>) -> Self
pub fn set_notify_code_configuration(self, input: Option<String>) -> Self
The identifier or Amazon Resource Name (ARN) of the notify code configuration that supplies the passcode policy and template defaults. When you do not specify a configuration, you must supply the template in the request.
Sourcepub fn get_notify_code_configuration(&self) -> &Option<String>
pub fn get_notify_code_configuration(&self) -> &Option<String>
The identifier or Amazon Resource Name (ARN) of the notify code configuration that supplies the passcode policy and template defaults. When you do not specify a configuration, you must supply the template in the request.
Sourcepub fn override_channel_parameters(self, input: ChannelParameters) -> Self
pub fn override_channel_parameters(self, input: ChannelParameters) -> Self
The channel-specific parameters used to render and deliver the one-time passcode for this request. The route that is derived from the channel and the origination identity selects the matching channel. When you do not specify channel parameters, the service uses the parameters from the referenced notify code configuration.
Sourcepub fn set_override_channel_parameters(
self,
input: Option<ChannelParameters>,
) -> Self
pub fn set_override_channel_parameters( self, input: Option<ChannelParameters>, ) -> Self
The channel-specific parameters used to render and deliver the one-time passcode for this request. The route that is derived from the channel and the origination identity selects the matching channel. When you do not specify channel parameters, the service uses the parameters from the referenced notify code configuration.
Sourcepub fn get_override_channel_parameters(&self) -> &Option<ChannelParameters>
pub fn get_override_channel_parameters(&self) -> &Option<ChannelParameters>
The channel-specific parameters used to render and deliver the one-time passcode for this request. The route that is derived from the channel and the origination identity selects the matching channel. When you do not specify channel parameters, the service uses the parameters from the referenced notify code configuration.
Sourcepub fn override_code_configuration_parameters(
self,
input: CodeConfigurationParameters,
) -> Self
pub fn override_code_configuration_parameters( self, input: CodeConfigurationParameters, ) -> Self
The per-send overrides for the passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. These values override the values from the referenced notify code configuration. When you do not specify a value, the value from the configuration is used, and if neither is set, the service default applies.
Sourcepub fn set_override_code_configuration_parameters(
self,
input: Option<CodeConfigurationParameters>,
) -> Self
pub fn set_override_code_configuration_parameters( self, input: Option<CodeConfigurationParameters>, ) -> Self
The per-send overrides for the passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. These values override the values from the referenced notify code configuration. When you do not specify a value, the value from the configuration is used, and if neither is set, the service default applies.
Sourcepub fn get_override_code_configuration_parameters(
&self,
) -> &Option<CodeConfigurationParameters>
pub fn get_override_code_configuration_parameters( &self, ) -> &Option<CodeConfigurationParameters>
The per-send overrides for the passcode policy parameters, including the code type, length, validity period, and maximum number of attempts. These values override the values from the referenced notify code configuration. When you do not specify a value, the value from the configuration is used, and if neither is set, the service default applies.
Sourcepub fn configuration_set_name(self, input: impl Into<String>) -> Self
pub fn configuration_set_name(self, input: impl Into<String>) -> Self
The name of the configuration set used to control how delivery events for the message are handled.
Sourcepub fn set_configuration_set_name(self, input: Option<String>) -> Self
pub fn set_configuration_set_name(self, input: Option<String>) -> Self
The name of the configuration set used to control how delivery events for the message are handled.
Sourcepub fn get_configuration_set_name(&self) -> &Option<String>
pub fn get_configuration_set_name(&self) -> &Option<String>
The name of the configuration set used to control how delivery events for the message are handled.
Sourcepub fn context(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn context(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to context.
To override the contents of this collection use set_context.
A map of custom key and value pairs that are propagated to the delivery events for this verification.
Sourcepub fn set_context(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_context(self, input: Option<HashMap<String, String>>) -> Self
A map of custom key and value pairs that are propagated to the delivery events for this verification.
Sourcepub fn get_context(&self) -> &Option<HashMap<String, String>>
pub fn get_context(&self) -> &Option<HashMap<String, String>>
A map of custom key and value pairs that are propagated to the delivery events for this verification.
Sourcepub fn reference_id(self, input: impl Into<String>) -> Self
pub fn reference_id(self, input: impl Into<String>) -> Self
A caller-supplied reference identifier that binds a send request to a later validate request. Specify the same value in both requests.
Sourcepub fn set_reference_id(self, input: Option<String>) -> Self
pub fn set_reference_id(self, input: Option<String>) -> Self
A caller-supplied reference identifier that binds a send request to a later validate request. Specify the same value in both requests.
Sourcepub fn get_reference_id(&self) -> &Option<String>
pub fn get_reference_id(&self) -> &Option<String>
A caller-supplied reference identifier that binds a send request to a later validate request. Specify the same value in both requests.