pub struct ValidateNotifyCodeVerificationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ValidateNotifyCodeVerification.
Validates a one-time passcode that a recipient submitted. Validation succeeds when the passcode matches, the validity period has not elapsed, and the maximum number of attempts has not been exceeded.
Implementations
Sourceimpl ValidateNotifyCodeVerificationFluentBuilder
impl ValidateNotifyCodeVerificationFluentBuilder
Sourcepub fn as_input(&self) -> &ValidateNotifyCodeVerificationInputBuilder
pub fn as_input(&self) -> &ValidateNotifyCodeVerificationInputBuilder
Access the ValidateNotifyCodeVerification as a reference.
Sourcepub async fn send(
self,
) -> Result<ValidateNotifyCodeVerificationOutput, SdkError<ValidateNotifyCodeVerificationError, HttpResponse>>
pub async fn send( self, ) -> Result<ValidateNotifyCodeVerificationOutput, SdkError<ValidateNotifyCodeVerificationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ValidateNotifyCodeVerificationOutput, ValidateNotifyCodeVerificationError, Self>
pub fn customize( self, ) -> CustomizableOperation<ValidateNotifyCodeVerificationOutput, ValidateNotifyCodeVerificationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn destination_identity(self, input: impl Into<String>) -> Self
pub fn destination_identity(self, input: impl Into<String>) -> Self
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn set_destination_identity(self, input: Option<String>) -> Self
pub fn set_destination_identity(self, input: Option<String>) -> Self
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn get_destination_identity(&self) -> &Option<String>
pub fn get_destination_identity(&self) -> &Option<String>
The recipient identifier. For the TEXT and VOICE channels, specify an E.164 phone number. For the WhatsApp channel, specify a WhatsApp address.
Sourcepub fn reference_id(self, input: impl Into<String>) -> Self
pub fn reference_id(self, input: impl Into<String>) -> Self
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourcepub fn set_reference_id(self, input: Option<String>) -> Self
pub fn set_reference_id(self, input: Option<String>) -> Self
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourcepub fn get_reference_id(&self) -> &Option<String>
pub fn get_reference_id(&self) -> &Option<String>
The caller-supplied reference identifier used to locate the verification. This value must match the value that you supplied to the SendNotifyCodeVerification operation.
Sourcepub fn code(self, input: impl Into<String>) -> Self
pub fn code(self, input: impl Into<String>) -> Self
The one-time passcode that the recipient submitted for validation.